@@ -6,7 +6,9 @@ import time
 from sentence_spliter.time_it import time_measure
 
 SYMBOLS = {
-    'quotation': re.compile('(["“”])'),
+    'quotation_left': re.compile('([“])'),
+    'quotation_right': re.compile('([”])'),
+    'quotation_en': re.compile('["＂]'),
     'bracket_left': re.compile('([{\[\(（【「])'),
     'bracket_right': re.compile('([\)\]}」】）])'),
     'comma': re.compile('([,，])'),
@@ -28,8 +30,8 @@ class Spliter:
         self.tmp_char = ''
 
         # -- parameter -- #
-
-    # -- filter -- #
+        self.tmp_char = []
+        # -- filter -- #
 
     # -- sentences segmentation -- #
     def cut_to_sentences(self, paragraph):
@@ -43,11 +45,11 @@ class Spliter:
         if len(paragraph) == 0:
             return []
         total_len = len(paragraph)
-        #s = time.time()
+        # s = time.time()
         for index, char in enumerate(paragraph):
             if char != '\n':
                 self._do_cut(char, index, paragraph, total_len)
-        #print(time.time() - s)
+        # print(time.time() - s)
         self.tmp_char = ''.join(self.tmp_char)
         if self.tmp_char:
             self.sentences.append(self.tmp_char)
@@ -61,13 +63,20 @@ class Spliter:
         :param paragraph:
         '''
         self.tmp_char.append(char)
-        if SYMBOLS['quotation'].match(char):  # "xx"，情况不切句 其他""情况切句
+        if SYMBOLS['quotation_right'].match(char):  # "xx"，情况不切句 其他""情况切句
+            self.count_quote = 0
+            if index + 1 >= total_len or SYMBOLS['end_symbols'].match(paragraph[index + 1]):  # 双引号后面不是逗号,就切分
+                self.add_to_sntnc()
+                return
+        elif SYMBOLS['quotation_en'].match(char):
             self.count_quote += 1
             if self.count_quote % 2 == 0:
                 self.count_quote = 0
-                if index + 1 >= total_len or not SYMBOLS['comma'].match(paragraph[index + 1]):#双引号后面不是逗号,就切分
+                if index + 1 >= total_len or SYMBOLS['end_symbols'].match(paragraph[index + 1]):  # 双引号后面不是切分符号不切分
                     self.add_to_sntnc()
                     return
+        elif SYMBOLS['quotation_left'].match(char):
+            self.count_quote += 1
         # -- 假定所有引号和括号都完美合上了 -- #
         elif SYMBOLS['bracket_left'].match(char):  # （）不切
             self.count_left_bracket += 1
@@ -80,7 +89,7 @@ class Spliter:
                 self.count_right_bracket = 0
             return
         elif self.is_valid_cut() and SYMBOLS['end_symbols'].match(char):  # 判断此字符是否为结束符号
-            if index + 1 >= total_len or not self._demical_char(char, index, paragraph):  # 判断是否是小数(是结束字符且不是小数)
+            if index + 1 >= total_len or not self._demical_char(char, index, paragraph) :  # 判断是否是小数(是结束字符且不是小数)
                 self.add_to_sntnc()
         return
 
@@ -112,3 +121,13 @@ class Spliter:
             return True
         else:
             return False
+
+if __name__ == '__main__':
+    spliter = Spliter()
+    text = '''
+“我不是一向眼睛里长满红筋。
+
+“我跟玛沙-加拉的王子订了婚。啊！一位多么体面的王子！
+
+“我费了好大气力……”'''
+    print('\n'.join(spliter.cut_to_sentences(text)))
\ No newline at end of file
